import { ActionFormData, ModalFormData } from '@minecraft/server-ui';
import { world } from '@minecraft/server';

function loadPlayerLocations(player) {
    const savedLocations = player.getDynamicProperty('savedLocations');
    if (savedLocations) {
        return JSON.parse(savedLocations); 
    }
    return []; 
}

function savePlayerLocations(player, locations) {
    player.setDynamicProperty('savedLocations', JSON.stringify(locations)); 
}

function showCombinedUI(player, locations) {
    const combinedUI = new ActionFormData()
        .title("Manage Locations")
        .button("Search Location", "textures/ui/magnifyingGlass");

    locations.forEach(location => {
        combinedUI.button(`${location.name}`, "textures/ui/mashup_world"); 
    });

    combinedUI.show(player).then((response) => {
        if (!response.canceled) {
            if (response.selection === 0) {
                showSearchLocationForm(player, locations);
            } else {
                const selectedLocation = locations[response.selection - 1];
                
                if (player.level >= 2) { 
                    if (player.dimension.id === selectedLocation.dimension) {
                        player.teleport(selectedLocation.position);
                        player.addLevels(-2); 
                        player.sendMessage("§aTeleported successfully! 2 XP levels were deducted.");
                    } else {
                        player.sendMessage("§cYou can't teleport from another dimension.");
                    }
                } else {
                    player.sendMessage("§cYou need at least 2 XP levels to teleport to this location.");
                }
            }
        }
    });
}

function showSearchLocationForm(player, locations) {
    const searchForm = new ModalFormData()
        .title("§l§3Search Location")
        .textField("Enter location name:", "Type location name..."); 

    searchForm.show(player).then((response) => {
        if (!response.canceled) {
            const searchQuery = response.formValues[0].toLowerCase();
            const filteredLocations = locations.filter(loc => loc.name.toLowerCase().includes(searchQuery));

            if (filteredLocations.length > 0) {
                showFilteredLocations(player, filteredLocations); 
            } else {
                player.sendMessage("§cNo locations found with that name.");
            }
        }
    });
}

function showFilteredLocations(player, locations) {
    const filteredUI = new ActionFormData()
        .title("§l§2Search Results");

    locations.forEach(location => {
        filteredUI.button(`§l§5${location.name}`, "textures/ui/mashup_world");
    });

    filteredUI.show(player).then((response) => {
        if (!response.canceled) {
            const selectedLocation = locations[response.selection];
            if (player.level >= 2) { 
                if (player.dimension.id === selectedLocation.dimension) {
                    player.teleport(selectedLocation.position);
                    player.addLevels(-2); 
                    player.sendMessage("§aTeleported successfully! 2 XP levels were deducted.");
                } else {
                    player.sendMessage("§cYou can't teleport from another dimension.");
                }
            } else {
                player.sendMessage("§cYou need at least 2 XP levels to teleport to this location.");
            }
        }
    });
}

world.afterEvents.itemUse.subscribe((event) => {
    const { source, itemStack } = event;
    if (itemStack.typeId === "zc:telecom") {
        const locations = loadPlayerLocations(source); 
        showCombinedUI(source, locations); 
    }
});
